Index: uspace/lib/libc/generic/ipc.c
===================================================================
--- uspace/lib/libc/generic/ipc.c	(revision 38c706cc8a6d3b4125c0704bdb5d9d6fe37e7fbf)
+++ uspace/lib/libc/generic/ipc.c	(revision 654b7dbfd1ebbe9e1b89c799d0698fa6cc06de69)
@@ -667,5 +667,5 @@
 }
 
 /** Wrapper for making IPC_M_DATA_SEND calls.
  *
  * @param phoneid	Phone that will be used to contact the receiving side.
@@ -675,18 +675,18 @@
  * @return		Zero on success or a negative error code from errno.h.
  */
-int ipc_data_send(int phoneid, void *src, size_t size)
-{
-	return ipc_call_sync_3_0(phoneid, IPC_M_DATA_SEND, 0, (ipcarg_t) src,
+int ipc_data_write_send(int phoneid, void *src, size_t size)
+{
+	return ipc_call_sync_3_0(phoneid, IPC_M_DATA_WRITE, 0, (ipcarg_t) src,
 	    (ipcarg_t) size);
 }
 
 /** Wrapper for receiving the IPC_M_DATA_SEND calls.
  *
  * This wrapper only makes it more comfortable to receive IPC_M_DATA_SEND calls
  * so that the user doesn't have to remember the meaning of each IPC argument.
  *
  * So far, this wrapper is to be used from within a connection fibril.
  *
  * @param callid	Storage where the hash of the IPC_M_DATA_SEND call will
  * 			be stored.
  * @param dst		Storage where the suggested destination address will
@@ -697,5 +697,5 @@
  * @return		Non-zero on success, zero on failure.
  */
-int ipc_data_receive(ipc_callid_t *callid, void **dst, size_t *size)
+int ipc_data_write_receive(ipc_callid_t *callid, void **dst, size_t *size)
 {
 	ipc_call_t data;
@@ -704,5 +704,5 @@
 
 	*callid = async_get_call(&data);
-	if (IPC_GET_METHOD(data) != IPC_M_DATA_SEND)
+	if (IPC_GET_METHOD(data) != IPC_M_DATA_WRITE)
 		return 0;
 	if (dst)
@@ -713,16 +713,16 @@
 }
 
 /** Wrapper for answering the IPC_M_DATA_SEND calls.
  *
  * This wrapper only makes it more comfortable to answer IPC_M_DATA_SEND calls
  * so that the user doesn't have to remember the meaning of each IPC argument.
  *
  * @param callid	Hash of the IPC_M_DATA_SEND call to answer.
  * @param dst		Final destination address for the IPC_M_DATA_SEND call.
  * @param size		Final size for the IPC_M_DATA_SEND call.
  *
  * @return		Zero on success or a value from @ref errno.h on failure.
  */
-ipcarg_t ipc_data_deliver(ipc_callid_t callid, void *dst, size_t size)
+ipcarg_t ipc_data_write_deliver(ipc_callid_t callid, void *dst, size_t size)
 {
 	return ipc_answer_3(callid, EOK, (ipcarg_t) dst, 0, (ipcarg_t) size);
@@ -667,5 +667,5 @@
 }
 
-/** Wrapper for making IPC_M_DATA_SEND calls.
+/** Wrapper for making IPC_M_DATA_WRITE calls.
  *
  * @param phoneid	Phone that will be used to contact the receiving side.
@@ -675,18 +675,18 @@
 }
 
-/** Wrapper for receiving the IPC_M_DATA_SEND calls.
- *
- * This wrapper only makes it more comfortable to receive IPC_M_DATA_SEND calls
+/** Wrapper for receiving the IPC_M_DATA_WRITE calls.
+ *
+ * This wrapper only makes it more comfortable to receive IPC_M_DATA_WRITE calls
  * so that the user doesn't have to remember the meaning of each IPC argument.
  *
@@ -675,18 +675,18 @@
  * So far, this wrapper is to be used from within a connection fibril.
  *
- * @param callid	Storage where the hash of the IPC_M_DATA_SEND call will
+ * @param callid	Storage where the hash of the IPC_M_DATA_WRITE call will
  * 			be stored.
  * @param dst		Storage where the suggested destination address will
@@ -713,16 +713,16 @@
 }
 
-/** Wrapper for answering the IPC_M_DATA_SEND calls.
- *
- * This wrapper only makes it more comfortable to answer IPC_M_DATA_SEND calls
+/** Wrapper for answering the IPC_M_DATA_WRITE calls.
+ *
+ * This wrapper only makes it more comfortable to answer IPC_M_DATA_WRITE calls
  * so that the user doesn't have to remember the meaning of each IPC argument.
  *
@@ -713,16 +713,16 @@
  * so that the user doesn't have to remember the meaning of each IPC argument.
  *
- * @param callid	Hash of the IPC_M_DATA_SEND call to answer.
- * @param dst		Final destination address for the IPC_M_DATA_SEND call.
- * @param size		Final size for the IPC_M_DATA_SEND call.
+ * @param callid	Hash of the IPC_M_DATA_WRITE call to answer.
+ * @param dst		Final destination address for the IPC_M_DATA_WRITE call.
+ * @param size		Final size for the IPC_M_DATA_WRITE call.
  *
  * @return		Zero on success or a value from @ref errno.h on failure.
